Learn R Programming

envnames (version 0.4.2)

get_obj_addresses_from_obj_names: Get the object addresses given their object names

Description

Get the object addresses given their object names

Usage

get_obj_addresses_from_obj_names(obj_names, envir = NULL)

Value

An array containing the memory address of the objects given in obj_names

or NULL if there is a problem evaluating the corresponding object in the given environment with eval().

Arguments

obj_names

array containing the name of the objects to retrieve. They can be given as full path names (e.g. "env1$x") and they can also be system or package environments given as e.g. ".GlobalEnv" or "R_GlobalEnv" or "baseenv()" or "package:base" or "package:stats", etc.

envir

environment where the objects exist (considering the object names are given with their full path to the object), or NULL if they exist in the global environment.