Get the user environments defined recursively within the given user environments
get_user_environments_in_user_envs_recursively(env_user_names, envir)a list containing the following elements:
fullnames the full names of the environments
addresses the addresses of the environments
locationaddresses the addresses of the locations of the environments
names of the user environments where the recursive search is carried out.
user environment where ALL environments in env_user_names live,
or NULL if those environments may live in different environments. In this case
the names of the environment where each env_user_names live is taken
from its names attribute.