This is the opposite operation of extract_root_and_last_member():
the root and its supposed member are put together using the
$ separator, as in env_of_envs$env1$x, where the root and
the member could be either env_of_envs$env1 and x or
env_of_envs and env1$x.
collapse_root_and_member(root, member)A string concatenating the root and the member names with the
$ symbol. If any of them is empty or NULL, the other name is returned
or "" if the other name is also empty or NULL.
String containing the root name to concatenate. It may be NULL or empty.
String containing the member name to concatenate. It may be NULL or empty.
extract_root_and_last_member()